#! /usr/bin/env python

import openturns as ot

ot.TESTPREAMBLE()

coll1 = ot.DistributionCollection(0)
coll1.add(ot.Normal(1.0, 2.5))
coll1.add(ot.Gamma(1.5, 3.0))
pointLow = ot.Point(0)
pointLow.add(coll1[0].computeQuantile(0.25)[0])
pointLow.add(coll1[1].computeQuantile(0.25)[0])
pointHigh = ot.Point(0)
pointHigh.add(coll1[0].computeQuantile(0.75)[0])
pointHigh.add(coll1[1].computeQuantile(0.75)[0])
coll2 = ot.DistributionCollection(0)
coll2.add(ot.Gamma(2.5, 2.0))
coll2.add(ot.Normal(3.0, 1.5))
# First, check the old constructor
evaluation = ot.MarginalTransformationEvaluation(coll1)
transformation = ot.MarginalTransformationGradient(evaluation)

print("transformation=", repr(transformation))
print(
    "transformation.gradient(",
    repr(pointLow),
    ")=",
    repr(transformation.gradient(pointLow)),
)
print(
    "finite difference gradient(",
    repr(pointLow),
    ")=",
    repr(ot.CenteredFiniteDifferenceGradient(1.0e-5, evaluation).gradient(pointLow)),
)
print(
    "transformation.gradient(",
    repr(pointHigh),
    ")=",
    repr(transformation.gradient(pointHigh)),
)
print(
    "finite difference gradient(",
    repr(pointHigh),
    ")=",
    repr(ot.CenteredFiniteDifferenceGradient(1.0e-5, evaluation).gradient(pointHigh)),
)
print("input dimension=", transformation.getInputDimension())
print("output dimension=", transformation.getOutputDimension())

# Second, check the constructor for old inverse transformation
evaluation = ot.MarginalTransformationEvaluation(
    coll1, ot.MarginalTransformationEvaluation.TO
)
transformation = ot.MarginalTransformationGradient(evaluation)
print("transformation=", repr(transformation))
uLow = ot.Point(coll1.getSize(), 0.25)
uHigh = ot.Point(coll1.getSize(), 0.75)
print("transformation.gradient(", repr(uLow), ")=", repr(transformation.gradient(uLow)))
print(
    "finite difference gradient(",
    repr(uLow),
    ")=",
    repr(ot.CenteredFiniteDifferenceGradient(1.0e-5, evaluation).gradient(uLow)),
)
print(
    "transformation.gradient(", repr(uHigh), ")=", repr(transformation.gradient(uHigh))
)
print(
    "finite difference gradient(",
    repr(uHigh),
    ")=",
    repr(ot.CenteredFiniteDifferenceGradient(1.0e-5, evaluation).gradient(uHigh)),
)
print("input dimension=", transformation.getInputDimension())
print("output dimension=", transformation.getOutputDimension())

# Third, check the constructor for the new transformation
evaluation = ot.MarginalTransformationEvaluation(coll1, coll2)
transformation = ot.MarginalTransformationGradient(evaluation)
print("transformation=", repr(transformation))
print(
    "transformation.gradient(",
    repr(pointLow),
    ")=",
    repr(transformation.gradient(pointLow)),
)
print(
    "finite difference gradient(",
    repr(pointLow),
    ")=",
    repr(ot.CenteredFiniteDifferenceGradient(1.0e-5, evaluation).gradient(pointLow)),
)
print(
    "transformation.gradient(",
    repr(pointHigh),
    ")=",
    repr(transformation.gradient(pointHigh)),
)
print(
    "finite difference gradient(",
    repr(pointHigh),
    ")=",
    repr(ot.CenteredFiniteDifferenceGradient(1.0e-5, evaluation).gradient(pointHigh)),
)
print("input dimension=", transformation.getInputDimension())
print("output dimension=", transformation.getOutputDimension())



#! /usr/bin/env python

import openturns as ot

ot.TESTPREAMBLE()


myFunc = ot.PointToFieldFunction()

print("myFunc=", myFunc)
# Get the input and output description
print("myFunc input description=", myFunc.getInputDescription())
print("myFunc output description=", myFunc.getOutputDescription())
# Get the input and output dimension
print("myFunc input dimension=", myFunc.getInputDimension())
print("myFunc output dimension=", myFunc.getOutputDimension())
# Get the number of calls
print("called ", myFunc.getCallsNumber(), " times")



#! /usr/bin/env python

import openturns as ot
import math
import openturns.testing as ott

ot.TESTPREAMBLE()

# Testing four algorithms on a function from R^3 to R.
f = ot.SymbolicFunction(["x", "y", "z"], ["sin(x) * cos(y) * exp(z)"])
lbIntegration = [0.0, 0.0, 0.0]
ubIntegration = [1.0, 1.0, 1.0]
valueRef = -math.sin(1.0) * (math.cos(1.0) - 1.0) * (math.e - 1.0)

for r in ot.CubaIntegration.GetAlgorithmNames():
    algoC = ot.CubaIntegration(r)
    value = algoC.integrate(f, ot.Interval(lbIntegration, ubIntegration))
    ott.assert_almost_equal(value[0], valueRef, 1.0e-3, 1.0e-3)

# Testing three algorithms on a function from R^3 to R^2.
f = ot.SymbolicFunction(
    ["x", "y", "z"],
    [
        "exp(-(x * x + y * y + z *z))",
        "(x / 2 * x / 2 + y / 3 * y / 3 + z / 4 * z / 4 - 1.125)",
    ],
)
lbIntegration = [0.0, 0.0, 1.0]
ubIntegration = [2.0, 3.0, 4.0]
valueRef = [0.108972129575688278, -0.375]

for r in ot.CubaIntegration.GetAlgorithmNames():
    if r == "suave":
        # Suave is quite inaccurate with these integrands, skipping.
        continue
    algoC = ot.CubaIntegration(r)
    if r == "vegas":
        # Vegas seemingly needs more favorable parameters there
        algoC.setMaximumRelativeError(5.0e-3)
        algoC.setMaximumAbsoluteError(5.0e-3)
        algoC.setMaximumCallsNumber(10000000)
    value = algoC.integrate(f, ot.Interval(lbIntegration, ubIntegration))
    ott.assert_almost_equal(value, valueRef, 1.0e-3, 1.0e-3)
